# JSON-lsp

JSON language server for JupyterLab

## Installation (coming soon)

```bash
conda install -c conda-forge jupyterlab jupyterlab-lsp json-lsp
```

### Development installation

```bash
conda install -c conda-forge yarn jupyterlab jupyterlab-lsp

git clone https://github.com/martinRenou/json-lsp && cd json-lsp

cd json_lsp && yarn install && cd ..
pip install .
```
